@@ -19,6 +19,10 @@ from global_chem.environment.emerging_perfluoroalkyls import EmergingPerFluoroAl
 from global_chem.materials.clay.montmorillonite_adsorption import MontmorilloniteAdsorption
 from global_chem.materials.polymers.common_monomer_repeating_units import CommonMonomerRepeatingUnits
 
+# Medicinal Chemistry - Cannabinoids
+
+from global_chem.medicinal_chemistry.cannabinoids.cannabinoids import Cannabinoids
+
 # Medicinal Chemistry - Warheads
 
 from global_chem.medicinal_chemistry.warheads.electrophillic_warheads_for_kinases import ElectrophilicWarheadsForKinases
@@ -343,11 +347,12 @@ class GlobalChem(object):
         'vitamins': Vitamins,                                                    # Suliman Sharif
         'open_smiles': OpenSmiles,                                               # Suliman Sharif
         'amino_acids': AminoAcids,                                               # Suliman Sharif
+        'pihkal': Pihkal,                                                        # Suliman Sharif
         'common_regex_patterns': CommonRegexPatterns,                            # Chris Burke & Suliman Sharif
     }
 
     __INCOMPLETE_NODES = {
-        'pihkal': Pihkal
+        'cannabinoids': Cannabinoids
     }
 
     def __init__(self, verbose=False):
@@ -957,6 +962,49 @@ class GlobalChem(object):
 
         return smarts
 
+    def get_smiles_by_iupac(self, iupac_key, return_network_path=False, return_all_network_paths=False):
+
+        '''
+
+        Get the SMILES by the IUPAC.
+
+        Arguments:
+            iupac_key (String): Key for the iupac.
+            return_network_path (Bool): whether the user wants the network path as well.
+            return_all_network_paths (Bool): return all the network paths
+
+        Returns:
+            definition (String): definiton of the iupac.
+            network_path (Dict): { definition: last network path in }
+            network_paths (Dict[List]): { definition: all_networks }
+        '''
+
+        network_paths = []
+        definition = ''
+
+        for node_key, node_value in self.__NODES__.items():
+
+            if node_key == 'global_chem' or node_key == 'common_regex_patterns':
+                continue
+
+            network_path = node_value.__module__
+            entity = node_value()
+            smiles = entity.get_smiles()
+
+            if iupac_key in smiles:
+
+                network_paths.append(network_path)
+                definition = smiles[iupac_key]
+
+        if return_network_path:
+            return { definition: network_paths[-1] }
+
+        elif return_all_network_paths:
+            return { definition: return_all_network_paths }
+
+        else:
+            return definition
+
     def set_node_value(self, node_key, value):
 
         '''
